package org.jenkinsci.plugins.p4.groovy;

import java.io.IOException;

import org.jenkinsci.plugins.p4.workspace.Workspace;
import org.kohsuke.stapler.DataBoundConstructor;

import hudson.EnvVars;
import hudson.FilePath;
import hudson.Launcher;
import hudson.model.Run;
import hudson.model.TaskListener;
import hudson.tasks.BuildStepMonitor;
import hudson.tasks.Builder;
import jenkins.tasks.SimpleBuildStep;

public class GetP4 extends Builder implements SimpleBuildStep {

	private final String credential;
	private final Workspace workspace;

	private P4Groovy p4Groovy;

	public String getCredential() {
		return credential;
	}

	public Workspace getWorkspace() {
		return workspace;
	}

	public P4Groovy getP4Groovy() {
		return p4Groovy;
	}

	@DataBoundConstructor
	public GetP4(String credential, Workspace workspace) {
		this.credential = credential;
		this.workspace = workspace;
	}

	@Override
	public BuildStepMonitor getRequiredMonitorService() {
		return BuildStepMonitor.NONE;
	}

	@Override
	public void perform(Run<?, ?> run, FilePath buildWorkspace, Launcher launcher, TaskListener listener)
			throws InterruptedException, IOException {

		// Set environment
		EnvVars envVars = run.getEnvironment(listener);
		envVars.put("NODE_NAME", envVars.get("NODE_NAME", "master"));
		workspace.setExpand(envVars);

		// Create Task
		GetP4Task task = new GetP4Task(credential, workspace);
		task.setListener(listener);

		p4Groovy = buildWorkspace.act(task);
	}
}