package org.jenkinsci.plugins.p4.groovy;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import org.jenkinsci.plugins.p4.client.ClientHelper;

import com.perforce.p4java.exception.P4JavaException;
import com.perforce.p4java.server.IOptionsServer;

public class P4Groovy implements Serializable {

	private static final long serialVersionUID = 1L;

	transient private final ClientHelper p4;
	transient private final IOptionsServer connection;

	public P4Groovy(ClientHelper p4) {
		this.p4 = p4;
		connection = p4.getConnection();
	}

	public void disconnect() throws Exception {
		p4.disconnect();
	}

	public String getClientName() {
		return p4.getClient().getName();
	}

	public String getUserName() {
		return connection.getUserName();
	}

	public Map<String, Object>[] run(String cmd, String args) throws P4JavaException {
		p4.log("Task: run command: " + cmd);

		List<String> argList = new ArrayList<String>();
		for (String arg : args.split(",")) {
			arg = arg.trim();
			argList.add(arg);
		}

		String[] array = argList.toArray(new String[0]);
		Map<String, Object>[] map = connection.execMapCmd(cmd, array, null);
		return map;
	}

	public Map<String, Object>[] save(String type, Map<String, Object> spec) throws P4JavaException {
		String[] array = { "-i" };
		Map<String, Object>[] map = connection.execMapCmd(type, array, spec);
		return map;
	}

	public Map<String, Object> fetch(String type, String id) throws P4JavaException {
		String[] array = { "-o", id };
		Map<String, Object>[] map = connection.execMapCmd(type, array, null);
		return map[0];
	}

}
